/*
Sample Sketch for the GL12864-STATION
*/

#include <U8g2lib.h>
#include <MCP23008.h>

U8G2_ST7920_128X64_1_HW_SPI u8g2(U8G2_R0, /* CS=*/ 10) ;
MCP23008 gpio(4) ; // I2Cアドレスは0x24(4)

#define BACKLIGHT 7
#define SOUNDER 8 // 接続に合わせて設定

// I/Oエクスパンダの初期化
void initSWandBACKLIGHT()
{
  gpio.begin() ; // デフォルトの初期化

   // タクトスイッチ端子をプルアップ付入力で初期化
  for (uint8_t i = 0; i < 7; i++)
    gpio.pinMode(i, INPUT_PULLUP) ;

  // バックライトを点ける
  gpio.digitalWrite(BACKLIGHT, HIGH) ;
}

void setup()
{
  u8g2.begin() ;  

  initSWandBACKLIGHT() ;
}

void loop()
{
  u8g2.firstPage();
  do {
    // タクトスイッチ2-5の変化は文字液晶に
    for (uint8_t i = 0; i < 7; i++) {
      if (gpio.digitalRead(i))
        u8g2.drawRFrame(18 * i, 16, 16, 24, 5);
      else
        u8g2.drawRBox(18 * i, 16, 16, 24, 5);
    }
    u8g2.setFont(u8g2_font_ncenB10_tr);
    u8g2.drawStr( 15, 62, "Push Button");
  } while ( u8g2.nextPage() );

  if (~gpio.readPORT() & 0x7F)
    tone(SOUNDER, 400) ;
  else
    noTone(SOUNDER) ;
    
  delay(100) ;
}