/*
Sample Sketch for the OLED-PLUS
*/

#include <U8g2lib.h>
#include <MCP23008.h>

U8G2_SSD1306_128X64_NONAME_1_HW_I2C u8g2(U8G2_R0, U8X8_PIN_NONE) ;
MCP23008 gpio ; // I2Cアドレスはデフォルト0x20(0)

#define LED1  6
#define LED2  7
#define SOUNDER 8

// I/Oエクスパンダの初期化
void initSWandLED()
{
  gpio.begin() ; // デフォルトの初期化

   // タクトスイッチ端子をプルアップ付入力で初期化
  for (uint8_t i = 0; i < 6; i++)
    gpio.pinMode(i, INPUT_PULLUP) ;

  // LED端子を出力で初期化し消灯
  gpio.pinMode(LED1, OUTPUT) ;
  gpio.pinMode(LED2, OUTPUT) ;
  gpio.digitalWrite(LED1, LOW) ;
  gpio.digitalWrite(LED2, LOW ) ;
}

void setup()
{
  u8g2.begin() ;  

  initSWandLED() ;
}

void loop()
{
  u8g2.firstPage();
  do {
    // タクトスイッチ0-3の変化は文字液晶に
    for (uint8_t i = 0; i < 4; i++) {
      if (gpio.digitalRead(i))
        u8g2.drawRFrame(32 * i, 16, 30, 24, 5);
      else
        u8g2.drawRBox(32 * i, 16, 30, 24, 5);
    }
    u8g2.setFont(u8g2_font_ncenB10_tr);
    u8g2.drawStr( 15, 62, "Push Button");
  } while ( u8g2.nextPage() );

  // タクトスイッチ4,5の変化はLEDに
  gpio.digitalWrite(LED1, !gpio.digitalRead(4));
  gpio.digitalWrite(LED2, !gpio.digitalRead(5));

  if (~gpio.readPORT() & 0x3F)
    tone(SOUNDER, 400) ;
  else
    noTone(SOUNDER) ;

  delay(100) ;
}
