/*
  Sample Sketch for the TFT18-PLUS

  http://www.microfan.jp/plus/tft18-plus
*/

#include <TFT.h>
#include <SPI.h>
#include <MCP23008.h>

#define TFT_CS  10 // TFTディスプレイのCS端子
#define TFT_DC  9 // TFTディスプレイのDC端子
#define TFT_RST 0 // TFTディスプレイのRESET端子

TFT tft18 = TFT(TFT_CS, TFT_DC, TFT_RST) ;

#define LED1  6
#define LED2  7
#define SOUNDER 8

MCP23008 gpio ; // I2Cアドレスはデフォルト0x20(0)

void setup()
{
  tft18.begin() ;
  tft18.initR(INITR_BLACKTAB) ; // 制御用ICの追加の初期化
  tft18.setRotation(1) ; // TFTディスプレイの向きの設定
  tft18.background(0, 0, 0) ;

  tft18.setTextSize(2) ;
  tft18.stroke(255, 255, 255) ;
  tft18.text("Push Button", 0, 10) ;

  gpio.begin(MCP23008_TFT18) ; // TFT18_PLUS用の初期化
}

void loop()
{
  tft18.stroke(255, 0, 0) ;
  for (int8_t i = 0 ; i < 4; i++) {
    if (gpio.digitalRead(i)) {
      tft18.fill(0, 0, 0);
      tft18.rect(40 * i + 5, 80, 30, 30) ;
    } else {
      tft18.fill(255, 127, 127);
      tft18.rect(40 * i + 5, 80, 30, 30) ;
    }
  }

  gpio.digitalWrite(LED1, !gpio.digitalRead(2));
  gpio.digitalWrite(LED2, !gpio.digitalRead(3));

  if (~gpio.readPORT() & 0x0F)
    tone(SOUNDER, 400) ;
  else
    noTone(SOUNDER) ;

  delay(200) ;
}