/*
MCP23008.cpp

Copyright (c) Kenichi KAKIZAKI. All right reserved.

http://www.microfan.jp/library/mcp23008
*/

#include <Arduino.h>
#include <Wire.h>
#ifdef __AVR
  #include <avr/pgmspace.h>
#elif defined(ESP8266)
  #include <pgmspace.h>
#endif
#include <MCP23008.h>

MCP23008::MCP23008(uint8_t addr) {
  if (addr > 7)
    addr = 7 ;

  i2caddr = addr ;
}

MCP23008::MCP23008(void) {
  MCP23008(0) ;
}

void MCP23008::begin(uint8_t device) {
  iodir = device ;
  pullup = iodir ;
  data = 0 ;

  Wire.begin() ;
  Wire.beginTransmission(MCP23008_ADDRESS | i2caddr) ;
  Wire.write((byte)MCP23008_IODIR) ;

  Wire.write(iodir) ; // MCP23008_IODIR
  Wire.write((byte)0x00) ;
  Wire.write((byte)0x00) ;
  Wire.write((byte)0x00) ;
  Wire.write((byte)0x00) ;
  Wire.write((byte)0x00) ;
  Wire.write(pullup) ; // MCP23008_GPPU
  Wire.write((byte)0x00) ;
  Wire.write((byte)0x00) ;
  Wire.write((byte)0x00) ;
  Wire.write(data) ; // MCP23008_OLAT

  Wire.endTransmission() ;
}

void MCP23008::begin(void) {
  begin(MCP23008_DEFAULT) ;
}

void MCP23008::pinMode(uint8_t p, uint8_t mode) {
  if (p > 7)
    return ;
  
  if (mode != OUTPUT) {
    iodir |= 1 << p ; 
  } else {
    iodir &= ~(1 << p) ;
  }

  write_register(MCP23008_IODIR, iodir) ;

  if (mode == INPUT_PULLUP) {
    pullup |= 1 << p ; 
  } else {
    pullup &= ~(1 << p) ;
  }

  write_register(MCP23008_GPPU, pullup) ;
}

uint8_t MCP23008::readPORT(void) {
  return read_register(MCP23008_GPIO) ;
}

void MCP23008::writePORT(uint8_t port) {
  data = port ;

  write_register(MCP23008_OLAT, port) ;
}

void MCP23008::writeIODIR(uint8_t port) {
  write_register(MCP23008_IODIR, port) ;
}

void MCP23008::writePU(uint8_t port) {
  write_register(MCP23008_GPPU, port) ;
}

void MCP23008::digitalWrite(uint8_t p, uint8_t d) {
  if (p > 7)
    return ;

  if (d != LOW) {
    data |= 1 << p ; 
  } else {
    data &= ~(1 << p) ;
  }

  writePORT(data) ;
}

uint8_t MCP23008::digitalRead(uint8_t p) {
  if (p > 7)
    return 0 ;

  return (readPORT() >> p) & 0x1 ;
}

/******* PRIVATE *******/

uint8_t MCP23008::read_register(uint8_t addr) {
  Wire.beginTransmission(MCP23008_ADDRESS | i2caddr) ;

  Wire.write((byte)addr) ;	

  Wire.endTransmission() ;

  Wire.requestFrom(MCP23008_ADDRESS | i2caddr, 1) ;

  return Wire.read() ;
}

void MCP23008::write_register(uint8_t addr, uint8_t data) {
  Wire.beginTransmission(MCP23008_ADDRESS | i2caddr) ;

  Wire.write((byte)addr) ;
  Wire.write((byte)data) ;

  Wire.endTransmission() ;
}
